# Width Fitting
`napari-bactmeasure` provides two fitting methods to calculate the width of a given bacterium, which have been 
developed to work with either fluorescence or phase contrast microscopy images.

## **Fluorescence microscopy fitting method**
::: micromorph.bacteria.fluorescence_fitting

## **Phase contrast microscopy fitting method**
::: micromorph.bacteria.phase_contrast_fitting